@@ -3,15 +3,18 @@
 #include "bucket.h"
 #include "collector.h"
 #include "complex.h"
+#include "sbkdate.h"
 #include "derived.h"
 #include "echo.h"
 #include "functions.h"
 #include "implicitconv.h"
 #include "overloadsort.h"
 #include "injectcode.h"
+#include "list.h"
 #include "listuser.h"
 #include "mapuser.h"
 #include "modifications.h"
+#include "modified_constructor.h"
 #include "multiple_derived.h"
 #include "noimplicitconversion.h"
 #include "nondefaultctor.h"
@@ -36,3 +39,4 @@
 #include "sometime.h"
 #include "virtualmethods.h"
 #include "voidholder.h"
+#include "valueandvirtual.h"
